/*
    Copyright (c) 2015 digitalSTROM AG, Zurich, Switzerland

    Authors: Enrique Robledo Arnuncio, for digitalSTROM AG <era@tegulan.com>

    This file is part of vdSM.

    vdSM is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 2 of the License.


    vdSM is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with vdSM. If not, see <http://www.gnu.org/licenses/>.
*/

#include "vdsmRole.h"

#include "base/log.h"

void vdsm_role_clear(VDSMRole *role) {
    role->collectable = false;
    role->collecting = false;
    role->master = false;
    role->auxiliary = false;
    role->noauto = false;
}

bool vdsm_role_sanitize(VDSMRole *role) {
    if (role->collectable && role->collecting) {
        report(LOG_ERR, "Incompatible vdSM roles: collectable and collecting\n");
        return false;
    }
    if (role->master && !role->collecting) {
        report(LOG_ERR, "Missing role: A master vdSM must also be collecting\n");
        return false;
    }
    if (role->noauto && !role->collectable) {
        report(LOG_ERR, "Missing role: A noauto vdSM must also be collectable\n");
        return false;
    }
    if (!role->collectable && !role->collecting) {
        report(LOG_DEBUG, "Legacy vdSM implicitly collectable.");
        role->collectable = true;
    }
    return true;
}
